==> ejc-bfyjerp-impl-3.0.0-20241031.083220-11-sources.jar: com/ejianc/business/bid/bean/TenderFundsEntity.java <==
package com.ejianc.business.bid.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 投标管理-投标保证金
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_tender_funds")
public class TenderFundsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="registration_id")
    private Long registrationId; // 项目报名表Id
    @TableField(value="opportunity_id")
    private Long opportunityId; // 商机登记表Id
    @TableField(value="opportunity_bill_code")
    private Long opportunityBillCode; // 商机登记单据编码
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="rec_acc_name")
    private String recAccName; // 收款账户户名
    @TableField(value="rec_acc_bank_name")
    private String recAccBankName; // 收款账户银行及开户行
    @TableField(value="rec_acc")
    private String recAcc; // 收款账号
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="employee_id")
    private Long employeeId; // 编制人id
    @TableField(value="employee_name")
    private String employeeName; // 编制人名称
    @TableField(value="payment_end_date")
    private Date paymentEndDate; // 截至缴纳时间
    @TableField(value="pay_acc_name")
    private String payAccName; // 打款人户名
    @TableField(value="pay_acc")
    private String payAcc; // 打款人账号
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bounds_status")
    private String boundsStatus; // 状态: 未缴/已缴/可退/已退
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value = "funds_back_id")
    private Long fundsBackId; //保证金退还单Id 为0时表示未被引用

    public Long getFundsBackId() {
        return fundsBackId;
    }

    public void setFundsBackId(Long fundsBackId) {
        this.fundsBackId = fundsBackId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getRegistrationId() {
        return registrationId;
    }

    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    public Long getOpportunityId() {
        return opportunityId;
    }

    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public String getRecAccName() {
        return recAccName;
    }

    public void setRecAccName(String recAccName) {
        this.recAccName = recAccName;
    }
    public String getRecAccBankName() {
        return recAccBankName;
    }

    public void setRecAccBankName(String recAccBankName) {
        this.recAccBankName = recAccBankName;
    }
    public String getRecAcc() {
        return recAcc;
    }

    public void setRecAcc(String recAcc) {
        this.recAcc = recAcc;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getPaymentEndDate() {
        return paymentEndDate;
    }

    public void setPaymentEndDate(Date paymentEndDate) {
        this.paymentEndDate = paymentEndDate;
    }
    public String getPayAccName() {
        return payAccName;
    }

    public void setPayAccName(String payAccName) {
        this.payAccName = payAccName;
    }
    public String getPayAcc() {
        return payAcc;
    }

    public void setPayAcc(String payAcc) {
        this.payAcc = payAcc;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getBoundsStatus() {
        return boundsStatus;
    }

    public void setBoundsStatus(String boundsStatus) {
        this.boundsStatus = boundsStatus;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250221.092234-138-sources.jar: com/ejianc/business/bid/bean/TenderFundsEntity.java <==
package com.ejianc.business.bid.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 投标管理-投标保证金
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_tender_funds")
public class TenderFundsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="registration_id")
    private Long registrationId; // 项目报名表Id
    @TableField(value="opportunity_id")
    private Long opportunityId; // 商机登记表Id
    @TableField(value="opportunity_bill_code")
    private String opportunityBillCode; // 商机登记单据编码
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="rec_acc_name")
    private String recAccName; // 收款账户户名
    @TableField(value="rec_acc_bank_name")
    private String recAccBankName; // 收款账户银行及开户行
    @TableField(value="rec_acc")
    private String recAcc; // 收款账号
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="employee_id")
    private Long employeeId; // 编制人id
    @TableField(value="employee_name")
    private String employeeName; // 编制人名称
    @TableField(value="payment_end_date")
    private Date paymentEndDate; // 截至缴纳时间
    @TableField(value="pay_acc_name")
    private String payAccName; // 打款人户名
    @TableField(value="pay_acc")
    private String payAcc; // 打款人账号
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bounds_status")
    private String boundsStatus; // 状态: 未缴/已缴/可退/已退
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value = "funds_back_id")
    private Long fundsBackId; //保证金退还单Id 为0时表示未被引用

    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getFundsBackId() {
        return fundsBackId;
    }

    public void setFundsBackId(Long fundsBackId) {
        this.fundsBackId = fundsBackId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getRegistrationId() {
        return registrationId;
    }

    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    public Long getOpportunityId() {
        return opportunityId;
    }

    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public String getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(String opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public String getRecAccName() {
        return recAccName;
    }

    public void setRecAccName(String recAccName) {
        this.recAccName = recAccName;
    }
    public String getRecAccBankName() {
        return recAccBankName;
    }

    public void setRecAccBankName(String recAccBankName) {
        this.recAccBankName = recAccBankName;
    }
    public String getRecAcc() {
        return recAcc;
    }

    public void setRecAcc(String recAcc) {
        this.recAcc = recAcc;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getPaymentEndDate() {
        return paymentEndDate;
    }

    public void setPaymentEndDate(Date paymentEndDate) {
        this.paymentEndDate = paymentEndDate;
    }
    public String getPayAccName() {
        return payAccName;
    }

    public void setPayAccName(String payAccName) {
        this.payAccName = payAccName;
    }
    public String getPayAcc() {
        return payAcc;
    }

    public void setPayAcc(String payAcc) {
        this.payAcc = payAcc;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getBoundsStatus() {
        return boundsStatus;
    }

    public void setBoundsStatus(String boundsStatus) {
        this.boundsStatus = boundsStatus;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    
}
